@@ -17,7 +17,7 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #include <math.h>
 
 extern "C" {
@@ -43,7 +43,7 @@ extern "C" {
 #define M_PI    3.14159265358979323846
 #endif
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 static LinkedObject *first = NULL;
 
@@ -2002,3 +2002,4 @@ SpeexCommon()
 
 #endif
 
+} // namespace ucommon
