@@ -17,18 +17,18 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #include <ctype.h>
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
-using namespace UCOMMON_NAMESPACE;
-
 #define MAP_HASH_SIZE   197
 #define MAP_PAGE_COUNT  255
 #define MAP_PAGE_SIZE (sizeof(void *[MAP_PAGE_COUNT]))
 #define MAP_PAGE_FIX (MAP_PAGE_SIZE / MAP_PAGE_COUNT)
 
+namespace ucommon {
+
 static unsigned char *page = NULL;
 static unsigned used = MAP_PAGE_SIZE;
 static TelTone::tonekey_t *hash[MAP_HASH_SIZE];
@@ -272,3 +272,4 @@ skip:
     return false;
 }
 
+} // namespace ucommon
