@@ -29,7 +29,7 @@
 #define __BYTE_ORDER    __LITTLE_ENDIAN
 #endif
 
-using namespace UCOMMON_NAMESPACE;
+using namespace ucommon;
 
 static const char *delfile = NULL;
 
